pro mdiv_pca

;Read in data
openr,1,'data/mdiv_patch.dat'
data=dblarr(17,83213)
readf,1,data
close,1

openr,1,'~/clust/k-means/patch/clusters.out.patch_pca.40'
data2=dblarr(1,83213)
readf,1,data2
close,1

openr,1,'data/gnames.dat'
;openr,1,'data/cnames.dat'
taxa=strarr(1,83213)
readf,1,taxa
close,1

nlon=360L
nlat=180L
;
print,'Searching entire Cenozoic'
lat=data[ 1,* ]
lon=data[ 2,* ]
clust_num_40=data2[ 0,* ]
names=taxa[ 0,* ]
x=dindgen(nlon)-179.5
y=dindgen(nlat)-89.5
zc=lonarr(nlon,nlat)
tc=lonarr(nlon,nlat)
bd=lonarr(nlon,nlat)
betai=dblarr(8)
beta=dblarr(nlon,nlat)
c=lonarr(nlon,nlat)
spdiv=lonarr(nlon,nlat)
p40=lonarr(nlon,nlat)
for mlon=0,nlon-1 do begin
   for mlat=0,nlat-1 do begin
      ttmp = gstring(lon,lat,names,x[mlon],y[mlat])
      ;
      ;;;tc is the number of unique genus/class names
      idx=where(lat ge y[mlat]-0.5 and lat lt y[mlat]+0.5 and lon ge x[mlon]-0.5 and lon lt x[mlon]+0.5,cnt)
      ;;;zc is the number of observations
      zc[mlon,mlat] = cnt
      if cnt gt 0 then begin
         tc[mlon,mlat]=n_elements(ttmp)
         ctemp_40=clust_num_40[idx]
         p40[mlon,mlat]=n_elements(ctemp_40[uniq(ctemp_40, sort(ctemp_40))])
         ; The following routine determines the beta-diversity 
         ; (difference) between each 1-square-degree-cell and the 
         ; 8 cells surrounding it. Cells that occur on any 
         ; of the four boundaries are without a neighboring cell
         ; on either one or two sides and are therefore compared to 
         ; cells back at the beginning. For example, a cell with 
         ; longitude from -179 to -180 is compared to its counterpart 
         ; with longitude from 179 to 180. A cell at -89 to -90 
         ; latitude is compared to its counterpart at 89 to 90 
         ; latitude. Below is a grid that illustrates this method
         ; where ! is the cell of interest. Its diversity count 
         ; is compared to each of the 8 cells around it and its beta
         ; diversity is taken to be the mean of all (up to 8) of 
         ; its beta (difference) diversities provided the neighboring
         ; cell is populated by at least one occurrence.
         ;
         ; NW N NE
         ; W  !  E
         ; SW S SE
         ;
         for j=0,7 do begin
            ; Choose the lon/lat indices (iqlon,iqlat) to query for unique
            ; genus/class names
            if j lt 3 then begin
               ; N
               if mlat eq 0 then iqlat=nlat-1 else iqlat=mlat+1
            endif else begin
               if j lt 5 then begin
                  iqlat = mlat
               endif else begin
                  ; S
                  if mlat eq nlat-1 then iqlat = 0 else iqlat = mlat-1
               endelse
            endelse
            if j eq 0 or j eq 3 or j eq 5 then begin
               ; W
               if mlon eq 0 then iqlon=nlon-1 else iqlon=mlon-1
            endif else begin
               if j eq 1 or j eq 6 then begin
                  iqlon = mlon
               endif else begin
                  ; E
                  if mlon eq nlon-1 then iqlon = 0 else iqlon = mlon+1
               endelse
            endelse
            ; Query for unique vectors of genus/class names
            case j of
               ; NW
               0: ttmp_nw = gstring(lon,lat,names,x[iqlon],y[iqlat])
               ; N
               1: ttmp_n = gstring(lon,lat,names,x[iqlon],y[iqlat])
               ; NE
               2: ttmp_ne = gstring(lon,lat,names,x[iqlon],y[iqlat])
               ; W
               3: ttmp_w = gstring(lon,lat,names,x[iqlon],y[iqlat])
               ; E
               4: ttmp_e = gstring(lon,lat,names,x[iqlon],y[iqlat])
               ; SW
               5: ttmp_sw = gstring(lon,lat,names,x[iqlon],y[iqlat])
               ; S
               6: ttmp_s = gstring(lon,lat,names,x[iqlon],y[iqlat])
               ; SE
               7: ttmp_se = gstring(lon,lat,names,x[iqlon],y[iqlat])
            endcase
         endfor
         ; Compute equation for beta diversity
         for j=0,7 do begin
            case j of
               0: ttmp_cmp = [ttmp,ttmp_nw]
               1: ttmp_cmp = [ttmp,ttmp_n]
               2: ttmp_cmp = [ttmp,ttmp_ne]
               3: ttmp_cmp = [ttmp,ttmp_w]
               4: ttmp_cmp = [ttmp,ttmp_e]
               5: ttmp_cmp = [ttmp,ttmp_sw]
               6: ttmp_cmp = [ttmp,ttmp_s]
               7: ttmp_cmp = [ttmp,ttmp_se]
            endcase
            gidx = where(ttmp_cmp eq '',tcnt)
            if tcnt eq 0 then begin
               ; the combined list of genus names in ttmp_cmp 
               ; (tc_cmp/2 is equivalent to Whittaker's variable 'S^bar')
               tc_cmp = n_elements(ttmp_cmp)
               ; the combined list of unique genus names in ttmp_cmp 
               ; (Whittaker's variable 'Sc')
               uttmp_cmp = ttmp_cmp[uniq(ttmp_cmp, sort(ttmp_cmp))]
               betai[j] = ( double(n_elements(uttmp_cmp)) / double(tc_cmp / 2.0 ) ) - 1
            endif else begin
               betai[j] = 0
            endelse
         endfor
         ;beta[mlon,mlat] = mean(betai,/double)
         idx=where(betai ne 0.,cnt)
         ; Connectivity: the number of grid cells with data or the 
         ; spatial continuity of the area
         if (cnt gt 0) then c[mlon,mlat]=cnt
         ; Beta diversity: the mean beta diversity of all non-zero cells
         if (cnt gt 0) then beta[mlon,mlat]=mean(betai(idx),/DOUBLE) else beta[mlon,mlat]=mean(betai,/DOUBLE)
         ; Find source pool diversity (excluding the grid cell of interest)
         ttmp_spi=[ ttmp_nw,ttmp_n,ttmp_ne,ttmp_w,ttmp_e,ttmp_sw,ttmp_s,ttmp_se ]
         ttmp_sp=n_elements(uniq(ttmp_spi, sort(ttmp_spi)))
         spdiv[mlon,mlat]=ttmp_sp
         ;
      endif else begin
         ; If no data in this gridcell, set tc, beta, spdiv to zero.
         tc[mlon,mlat]=0
         beta[mlon,mlat]=0
         spdiv[mlon,mlat]=0
      endelse
   endfor ; mlat
endfor ; mlon
;
; Analyze only the non-zero grid cells
idx=where(tc gt 0,cnt)
tc=tc[idx]
beta=beta[idx]
c=c[idx]
p40=p40[idx]
; Pearson correlations
tc_p40_pcorr=correlate(tc,p40,/double)
beta_p40_pcorr=correlate(beta,p40,/double)
c_p40_pcorr=correlate(c,p40,/double)
; Spearman correlations
tc_p40_rcorr=r_correlate(tc,p40)
beta_p40_rcorr=r_correlate(beta,p40)
c_p40_rcorr=r_correlate(c,p40)
print,'Pearson Corr: Alpha Div/Patch40',tc_p40_pcorr
print,'Pearson Corr: Beta Div/Patch40',beta_p40_pcorr
print,'Spearman Corr: Alpha Div/Patch40',tc_p40_rcorr
print,'Spearman Corr: Beta Div/Patch40',beta_p40_rcorr
print,'Spearman Corr: Connectivity/Patch40',c_p40_rcorr
;
return
end
