#!/bin/bash
intervals=mdiv_iname
t=(0 0.01 2.6 5.3 11.6 16.0 23.0 28.4 33.9 40.4 48.6 55.8)
iname="Holocene Pleistocene Pliocene Late_Miocene Middle_Miocene Early_Miocene Late_Oligocene Early_Oligocene Late_Eocene Middle_Eocene Early_Eocene"
jname=($iname)
fname1=mdiv_nam
fname2=mdiv_eur
fname3=mdiv_eas
fname4=mdiv_meso_tmp
fname5=mdiv_table.out
fname_splot_nam=~/plt/mdiv/data/mdiv_splot_nam.dat
fname_splot_we=~/plt/mdiv/data/mdiv_splot_we.dat
fname_splot_ea=~/plt/mdiv/data/mdiv_splot_ea.dat
tmp_file=tmp.`date "+%Y%m%d.%02k%M%S"`
rm $intervals $fname1 $fname2 $fname3 $fname4 $fname5
#
### Query data for scatter plot
### Southeastern North America
psql sed_rock -tc "select adiv,bdiv,patch40,connectivity/8::float from mdiv_meso where latdec>23 and latdec<45 and londec>-97 and londec<-72;" | sed '/^$/d' | awk -F'|' '{printf "%s %s %s %s\n", $1,$2,$3,$4;}' >> $fname_splot_nam
### Western Europe
psql sed_rock -tc "select adiv,bdiv,patch40,connectivity/8::float from mdiv_meso where latdec>30 and latdec<60 and londec>-10 and londec<30;" | sed '/^$/d' | awk -F'|' '{printf "%s %s %s %s\n", $1,$2,$3,$4;}' >> $fname_splot_we
### Eastern Asia
psql sed_rock -tc "select adiv,bdiv,patch40,connectivity/8::float from mdiv_meso where latdec>20 and latdec<70 and londec>120 and londec<160;" | sed '/^$/d' | awk -F'|' '{printf "%s %s %s %s\n", $1,$2,$3,$4;}' >> $fname_splot_ea
#
for i in $iname; do
   ### Southeastern North America
   psql sed_rock -tc "select avg(adiv),avg(bdiv),avg(patch40),avg(spdiv),avg(connectivity)/8 from mdiv_meso where interval='$i' and latdec>23 and latdec<45 and londec>-97 and londec<-72;" | sed '/^$/d' | awk -F'|' '{printf "%1.1f & %1.2f & %1.1f & %1.1f & %1.2f \\\\\n", $1,$2,$3,$4,$5;}' >> $fname1
   ### Western Europe
   psql sed_rock -tc "select avg(adiv),avg(bdiv),avg(patch40),avg(spdiv),avg(connectivity)/8 from mdiv_meso where interval='$i' and latdec>30 and latdec<60 and londec>-10 and londec<30;" | sed '/^$/d' | awk -F'|' '{printf "%1.1f & %1.2f & %1.1f & %1.1f & %1.2f \\\\\n", $1,$2,$3,$4,$5;}' >> $fname2
   ### Eastern Asia
   psql sed_rock -tc "select avg(adiv),avg(bdiv),avg(patch40),avg(spdiv),avg(connectivity)/8 from mdiv_meso where interval='$i' and latdec>20 and latdec<70 and londec>120 and londec<160;" | sed '/^$/d' | awk -F'|' '{printf "%1.1f & %1.2f & %1.1f & %1.1f & %1.2f \\\\ \\'hline'\n", $1,$2,$3,$4,$5;}' >> $fname3
done
#
for ((i=1;i<=11;i++)); do
   head -n+$i $fname1 | tail -n-1 >> $fname4
   head -n+$i $fname2 | tail -n-1 >> $fname4
   head -n+$i $fname3 | tail -n-1 >> $fname4
done
#
for i in $iname; do
   echo '\multirow{3}{*}{'$i'} & E. N.Am. ' >> $intervals
   echo ' & Europe ' >> $intervals
   echo ' & E. Asia ' >> $intervals
done
#
### Parse LaTex table commands to output file for 1st table
echo '%% TABLE'  >> $fname5
echo '\begin{table}[!h]'  >> $fname5
echo '%% Establish floating table in minipage environment so footnotes'  >> $fname5
echo '%% will be placed at end of minipage environ, not end of page.'  >> $fname5
echo '  \begin{minipage}[t]{1.0\linewidth}\centering'  >> $fname5
echo '    \caption[]{Data composition. Generic abundances of all data, select phylogenetic classes, and the number of habitat types that occur within each sub-epoch are listed in chronological order.\label{tbl:mdiv_data_composition} }'  >> $fname5
echo '  \vspace{5mm}'  >> $fname5
echo '    \begin{tabular}{lr@{.}lr@{.}lccrcr}'  >> $fname5
echo '      & \multicolumn{2}{c}{Time\footnote{Epoch ages correspond to the age of the base of each unit.}} & \multicolumn{2}{c}{Duration} & \multicolumn{1}{c}{Bivalve} & \multicolumn{1}{c}{Gastropod} & \multicolumn{1}{c}{Total} & \multicolumn{1}{c}{Habitat} & \multicolumn{1}{c}{Div.\footnote{Diversity Density is calculated as genera/patches.}}  \\'  >> $fname5
echo '      Interval & \multicolumn{2}{c}{(Ma)} & \multicolumn{2}{c}{(Myr)} & \multicolumn{1}{c}{Genera} & \multicolumn{1}{c}{Genera} & \multicolumn{1}{c}{Genera} & \multicolumn{1}{c}{Patches} & \multicolumn{1}{c}{Density}  \\ \hline \\'  >> $fname5
#
### Query data for and parse to output file
for ((cnt=0;cnt<=10;cnt++)); do
   top=${cnt}+1
   psql sed_rock -tc "select ${t[$top]} as t,(${t[$top]}-${t[$cnt]}) as dur,(select count(distinct(genus_name)) from mdiv_patch where class_name='Bivalvia' and ma_mid>=${t[$cnt]} and ma_mid<${t[$top]}) as gb,(select count(distinct(genus_name)) from mdiv_patch where class_name='Gastropoda' and ma_mid>=${t[$cnt]} and ma_mid<${t[$top]}) as gg,count(distinct(genus_name)) as g,count(distinct(clust_num_40)) as h,count(distinct(genus_name))/count(distinct(clust_num_40))::float as den from mdiv_patch where ma_mid>=${t[$cnt]} and ma_mid<${t[$top]};" | sed '/^$/d' | awk -F'|' '{printf "%s & %s & %s & %s & %s & %s & %1.1f  \\\\\n", $1,$2,$3,$4,$5,$6,$7;}' > $tmp_file
   echo ${jname[$cnt]} ' &' | sed 's/_/ /' | paste - $tmp_file >> $fname5
done
rm $tmp_file
#
### Parse LaTex table commands to output file for 1st table
echo '    \end{tabular}'  >> $fname5
echo '  \end{minipage}'  >> $fname5
echo '\end{table}'  >> $fname5
echo '\pagebreak'  >> $fname5
echo '' >> $fname5
#
### Parse results to output file for 2nd table
echo '%% TABLE'  >> $fname5
echo '\begin{table}[!h]'  >> $fname5
echo '%% Establish floating table in minipage environment so footnotes'  >> $fname5
echo '%% will be placed at end of minipage environ, not end of page.'  >> $fname5
echo '  \begin{minipage}[t]{1.0\linewidth}\centering'  >> $fname5
echo '  \caption[Local diversity by region]{Local diversity by region. Mean abundances per assemblage ($1^\circ$ longitude $\times$ $1^\circ$ latitude) for alpha, beta, habitat type, and source pool diversity, as well as connectivity are given for three sub-epochs-- the Pleistocene, the Late Miocene for which regional tectonism was particularly active in eastern Asia as the Sea of Japan opened, and the middle Eocene of the Mediterranean and Europe which was characterized by the closure of the Tethys Sea.}\label{tbl:mdiv_regional_diversity_supp}' >> $fname5
echo '  \vspace{5mm}'  >> $fname5
echo '    \begin{tabular}{llrrrrc}'  >> $fname5
echo '        Interval '  >> $fname5
echo '	& Region'  >> $fname5
echo '        & \multicolumn{1}{c}{$\alpha$}'  >> $fname5
echo '        & \multicolumn{1}{c}{$\beta$}'  >> $fname5
echo '        & \multicolumn{1}{c}{Hab. Types}'  >> $fname5
echo '        & \multicolumn{1}{c}{Source Pool}'  >> $fname5
echo '        & \multicolumn{1}{c}{Connectivity}  \\ \hline'  >> $fname5
paste $intervals $fname4 | sed 's/\t/ \& /g;s/_/ /g' >> $fname5
echo '    \end{tabular}'  >> $fname5
echo '  \end{minipage}'  >> $fname5
echo '\end{table}'  >> $fname5
echo '' >> $fname5
#
### Parse results to output file for 3rd table
echo '' >> $fname5
echo '%% TABLE' >> $fname5
echo '\begin{table}[!h]' >> $fname5
echo '  \begin{minipage}[t]{1.0\linewidth}\centering' >> $fname5
echo '    \caption[]{Correlations. Each column lists the Spearman correlation ($\rho$) for $\alpha$--diversity and $\beta$--diversity, to various parameters. Footnote marks indicate significant correlations (two--tailed test).\label{tbl:mdiv_correlations} }' >> $fname5
echo '    \vspace{5mm}' >> $fname5
echo '    \begin{tabular}[c]{lcc}' >> $fname5
echo '      Parameter & $\alpha$ & $\beta$  \\' >> $fname5
echo '      \hline \\' >> $fname5
### Parse query results to output file for 3rd table
psql sed_rock -tc "select parameter,a_rcorr,b_rcorr from mdiv_cen_corr" | sed '/^$/d;s/^ //;s/_/ /' |  awk -F'|' '{printf "%s & %1.3f & %1.3f  \\\\\n", $1,$2,$3;}' >> $fname5
echo '    \end{tabular}' >> $fname5
echo '  \end{minipage}' >> $fname5
echo '\end{table}' >> $fname5
### Clean up
rm $intervals $fname1 $fname2 $fname3 $fname4
